pub struct Engine { /* private fields */ }Expand description
The layout engine.
Implementations
Sourceimpl Engine
impl Engine
pub fn new() -> Self
Sourcepub fn new_deterministic() -> Result<Self>
pub fn new_deterministic() -> Result<Self>
Create an engine that resolves fonts without system font discovery.
Sourcepub fn set_caller_font_aliases(&mut self, aliases: &[(String, String)])
pub fn set_caller_font_aliases(&mut self, aliases: &[(String, String)])
Set byte-free caller aliases from requested family to loaded family.
Sourcepub fn layout(&mut self, input: &LayoutInput) -> Result<LayoutResult>
pub fn layout(&mut self, input: &LayoutInput) -> Result<LayoutResult>
Lay out the entire document.