pub enum RevisionView {
Accepted,
Tracked,
}Expand description
The tracked-revision projection used for Word layout.
Variants
Accepted
Render the document as though all modeled revisions were accepted.
Tracked
Render both sides of modeled revisions with tracked decorations.