pub struct Section {
pub blocks: Vec<LayoutBlock>,
pub geometry: PageGeometry,
pub header_footer: Option<HeaderFooterContent>,
pub title_pg: bool,
pub page_number_start: Option<usize>,
}Expand description
A section with its blocks, geometry, and header/footer content.
Fields
blocks: Vec<LayoutBlock>geometry: PageGeometrytitle_pg: boolWhether this section uses a different first page header/footer.
page_number_start: Option<usize>Displayed page number assigned to the first page of this section.